

from .ED448 import ED448

def DUOM (GROUP):
	import click
	@GROUP.group ("DUOM")
	def GROUP ():
		pass
		
	import click
	@GROUP.command ("")
	def EXAMPLE ():	
		print ("START")



		return;
		
	ED448 (GROUP)

	return;